@@ -26,19 +26,21 @@ import configparser
 import json
 import os.path
 import shutil
+import typing as tp
 import urllib.request
 from contextlib import asynccontextmanager
 from collections import namedtuple
 from cytoolz.dicttoolz import get_in
 from datetime import datetime
 from iterfzf import iterfzf
-from tempfile import TemporaryDirectory
+from functools import partial
 from uuid import uuid4 as uuid
 
 import remt
 from .error import *
 from .indexer import ann_text, fmt_ann_text
-from .meta import BASE_DIR, fn_path, read_meta, fn_metadata, create_metadata
+from .meta import BASE_DIR, fn_path, cache_dir, read_meta, sync_meta, \
+    fn_metadata, create_metadata
 from .pdf import pdf_open
 from .util import flatten
 
@@ -87,30 +89,34 @@ def read_config():
     return cp
 
 @asynccontextmanager
-async def remt_ctx():
+async def remt_ctx(dir_base: tp.Optional[str]=None):
     """
     Create a `remt` project context.
 
     The function is an asynchronous context manager.
     """
     config = read_config()
-
     host = config.get('connection', 'host')
     user = config.get('connection', 'user')
     password = config.get('connection', 'password')
 
+    if dir_base is None:
+        dir_base = cache_dir(host)
+
+    mkdir = partial(os.makedirs, exist_ok=True)
+    dir_meta = os.path.join(dir_base, 'metadata')
+    dir_data = os.path.join(dir_base, 'data')
+
+    mkdir(dir_meta)
+    mkdir(dir_data)
+
     try:
         ctx_conn = asyncssh.connect(host, username=user, password=password)
         async with ctx_conn as conn:
             async with conn.start_sftp_client() as sftp:
-                with TemporaryDirectory() as dir_base:
-                    dir_meta = os.path.join(dir_base, 'metadata')
-                    dir_data = os.path.join(dir_base, 'data')
-                    os.mkdir(dir_meta)
-                    os.mkdir(dir_data)
-
-                    meta = await read_meta(sftp, dir_meta)
-                    yield RemtContext(config, sftp, dir_meta, meta, dir_data)
+                await sync_meta(sftp, dir_meta)
+                meta = read_meta(dir_meta)
+                yield RemtContext(config, sftp, dir_meta, meta, dir_data)
     except OSError as ex:
         if ex.errno == 101:
             raise ConnectionError(
@@ -118,6 +124,8 @@ async def remt_ctx():
             )
         else:
             raise
+    finally:
+        shutil.rmtree(dir_data)
 
 def norm_path(path):
     """
@@ -302,7 +310,7 @@ async def cmd_mkdir(args):
 #
 async def cmd_export(args):
     path = norm_path(args.input)
-    f_export = _export_remt if args.remt_render else _export_rm
+    f_export = _export_remt if args.renderer == 'remt' else _export_rm
 
     async with remt_ctx() as ctx:
         if path == '%i':
